@@ -6,12 +6,13 @@ import asyncio
 import json
 import os
 import random
+import readline
 import sys
 from typing import Generator
 from typing import Optional
 import uuid
 
-import tls_client
+import requests
 import websockets.client as websockets
 
 DELIMITER = "\x1e"
@@ -76,25 +77,22 @@ class ChatHubRequest:
         self.conversation_signature: str = conversation_signature
         self.invocation_id: int = invocation_id
 
-    def update(
-        self,
-        prompt: str,
-    ) -> None:
+    def update(self, prompt: str, options: list = None) -> None:
         """
         Updates request object
         """
+        if options is None:
+            options = [
+                "deepleo",
+                "enable_debug_commands",
+                "disable_emoji_spoken_text",
+                "enablemm",
+            ]
         self.struct = {
             "arguments": [
                 {
                     "source": "cib",
-                    "optionsSets": [
-                        "nlu_direct_response_filter",
-                        "deepleo",
-                        "enable_debug_commands",
-                        "disable_emoji_spoken_text",
-                        "responsible_ai_policy_235",
-                        "enablemm",
-                    ],
+                    "optionsSets": options,
                     "isStartOfSession": self.invocation_id == 0,
                     "message": {
                         "author": "user",
@@ -121,26 +119,31 @@ class Conversation:
     Conversation API
     """
 
-    def __init__(self, cookiePath: str = "") -> None:
+    def __init__(self, cookiePath: str = "", cookies: dict | None = None) -> None:
         self.struct: dict = {
             "conversationId": None,
             "clientId": None,
             "conversationSignature": None,
             "result": {"value": "Success", "message": None},
         }
-        self.session = tls_client.Session(client_identifier="chrome_108")
-        if cookiePath == "":
-            f = open(os.environ.get("COOKIE_FILE"), encoding="utf-8").read()
+        self.session = requests.Session()
+        self.session.headers.update({"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36"})
+        if cookies is not None:
+            cookie_file = cookies
         else:
-            f = open(cookiePath, encoding="utf8").read()
-        cookie_file = json.loads(f)
+            f = (
+                open(cookiePath, encoding="utf8").read()
+                if cookiePath
+                else open(os.environ.get("COOKIE_FILE"), encoding="utf-8").read()
+            )
+            cookie_file = json.loads(f)
         for cookie in cookie_file:
             self.session.cookies.set(cookie["name"], cookie["value"])
         url = "https://edgeservices.bing.com/edgesvc/turing/conversation/create"
         # Send GET request
         response = self.session.get(
             url,
-            timeout_seconds=30,
+            timeout=30,
             headers=HEADERS,
             allow_redirects=True,
         )
@@ -179,15 +182,7 @@ class ChatHub:
         Ask a question to the bot
         """
         # Check if websocket is closed
-        if self.wss:
-            if self.wss.closed:
-                self.wss = await websockets.connect(
-                    "wss://sydney.bing.com/sydney/ChatHub",
-                    extra_headers=HEADERS,
-                    max_size=None,
-                )
-                await self.__initial_handshake()
-        else:
+        if self.wss and self.wss.closed or not self.wss:
             self.wss = await websockets.connect(
                 "wss://sydney.bing.com/sydney/ChatHub",
                 extra_headers=HEADERS,
@@ -221,9 +216,8 @@ class ChatHub:
         """
         Close the connection
         """
-        if self.wss:
-            if not self.wss.closed:
-                await self.wss.close()
+        if self.wss and not self.wss.closed:
+            await self.wss.close()
 
 
 class Chatbot:
@@ -231,9 +225,11 @@ class Chatbot:
     Combines everything to make it seamless
     """
 
-    def __init__(self, cookiePath: str = "") -> None:
+    def __init__(self, cookiePath: str = "", cookies: dict | None = None) -> None:
         self.cookiePath: str = cookiePath
-        self.chat_hub: ChatHub = ChatHub(Conversation(self.cookiePath))
+        self.cookies: dict | None = cookies
+        self.chat_hub: ChatHub = ChatHub(
+            Conversation(self.cookiePath, self.cookies))
 
     async def ask(self, prompt: str) -> dict:
         """
@@ -242,6 +238,7 @@ class Chatbot:
         async for final, response in self.chat_hub.ask_stream(prompt=prompt):
             if final:
                 return response
+        self.chat_hub.wss.close()
 
     async def ask_stream(self, prompt: str) -> Generator[str, None, None]:
         """
@@ -261,7 +258,7 @@ class Chatbot:
         Reset the conversation
         """
         await self.close()
-        self.chat_hub = ChatHub(Conversation(self.cookiePath))
+        self.chat_hub = ChatHub(Conversation(self.cookiePath, self.cookies))
 
 
 def get_input(prompt):
@@ -271,6 +268,11 @@ def get_input(prompt):
     # Display the prompt
     print(prompt, end="")
 
+    if args.enter_once:
+        user_input = input()
+        print()
+        return user_input
+
     # Initialize an empty list to store the input lines
     lines = []
 
@@ -339,10 +341,11 @@ if __name__ == "__main__":
         !help for help
 
         Type !exit to exit
-        Enter twice to send message
+        Enter twice to send message or set --enter-once to send one line message
     """,
     )
     parser = argparse.ArgumentParser()
+    parser.add_argument("--enter-once", action="store_true")
     parser.add_argument("--no-stream", action="store_true")
     parser.add_argument(
         "--cookie-file",
